==> mindc-0.2.3a-src.tar.bz2: mindc-0.2.3a/idl-frontend/src/main/java/org/ow2/mind/idl/CacheIDLLoader.java <==
/**
 * Copyright (C) 2009 STMicroelectronics
 *
 * This file is part of "Mind Compiler" is free software: you can redistribute 
 * it and/or modify it under the terms of the GNU Lesser General Public License 
 * as published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT 
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Contact: mind@ow2.org
 *
 * Authors: Matthieu Leclercq
 * Contributors: 
 */

package org.ow2.mind.idl;

import java.util.HashMap;
import java.util.Map;

import org.objectweb.fractal.adl.ADLException;
import org.objectweb.fractal.adl.ContextLocal;
import org.ow2.mind.idl.ast.IDL;

/**
 * Simple delegating loader that manage a cache of already loaded definitions.
 * The cache is different for each given <code>context</code> (see
 * {@link ContextLocal}).
 */
public class CacheIDLLoader extends AbstractIDLLoader implements IDLCache {

  protected final ContextLocal<Map<String, IDL>> contextualCache = new ContextLocal<Map<String, IDL>>();

  // ---------------------------------------------------------------------------
  // Implementation of the IDLLoader interface
  // ---------------------------------------------------------------------------

  public IDL load(final String name, final Map<Object, Object> context)
      throws ADLException {
    final Map<String, IDL> cache = getCache(context);
    IDL idl = cache.get(name);

    if (idl == null) {
      idl = clientIDLLoaderItf.load(name, context);
      cache.put(name, idl);
    }

    return idl;
  }

  // ---------------------------------------------------------------------------
  // Implementation of the IDLCache interface
  // ---------------------------------------------------------------------------

  public IDL getInCache(final String name, final Map<Object, Object> context) {
    final Map<String, IDL> cache = getCache(context);
    return cache.get(name);
  }

  public void addInCache(final IDL d, final Map<Object, Object> context) {
    final Map<String, IDL> cache = getCache(context);
    cache.put(d.getName(), d);
  }

  // ---------------------------------------------------------------------------
  // Utility methods
  // ---------------------------------------------------------------------------

  protected Map<String, IDL> getCache(final Map<Object, Object> context) {
    Map<String, IDL> cache = contextualCache.get(context);
    if (cache == null) {
      cache = new HashMap<String, IDL>();
      contextualCache.set(context, cache);
    }
    return cache;
  }
}

==> mindc-0.3-src.tar.bz2: mindc-0.3/idl-frontend/src/main/java/org/ow2/mind/idl/CacheIDLLoader.java <==
/**
 * Copyright (C) 2009 STMicroelectronics
 *
 * This file is part of "Mind Compiler" is free software: you can redistribute 
 * it and/or modify it under the terms of the GNU Lesser General Public License 
 * as published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT 
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Contact: mind@ow2.org
 *
 * Authors: Matthieu Leclercq
 * Contributors: 
 */

package org.ow2.mind.idl;

import java.util.HashMap;
import java.util.Map;

import org.objectweb.fractal.adl.ADLException;
import org.objectweb.fractal.adl.ContextLocal;
import org.ow2.mind.idl.IDLLoader.AbstractDelegatingIDLLoader;
import org.ow2.mind.idl.ast.IDL;

import com.google.inject.Singleton;

/**
 * Simple delegating loader that manage a cache of already loaded definitions.
 * The cache is different for each given <code>context</code> (see
 * {@link ContextLocal}).
 */
@Singleton
public class CacheIDLLoader extends AbstractDelegatingIDLLoader
    implements
      IDLCache {

  protected final ContextLocal<Map<String, IDL>> contextualCache = new ContextLocal<Map<String, IDL>>();

  // ---------------------------------------------------------------------------
  // Implementation of the IDLLoader interface
  // ---------------------------------------------------------------------------

  public IDL load(final String name, final Map<Object, Object> context)
      throws ADLException {
    final Map<String, IDL> cache = getCache(context);
    IDL idl = cache.get(name);

    if (idl == null) {
      idl = clientIDLLoaderItf.load(name, context);
      cache.put(name, idl);
    }

    return idl;
  }

  // ---------------------------------------------------------------------------
  // Implementation of the IDLCache interface
  // ---------------------------------------------------------------------------

  public IDL getInCache(final String name, final Map<Object, Object> context) {
    final Map<String, IDL> cache = getCache(context);
    return cache.get(name);
  }

  public void addInCache(final IDL d, final Map<Object, Object> context) {
    final Map<String, IDL> cache = getCache(context);
    cache.put(d.getName(), d);
  }

  // ---------------------------------------------------------------------------
  // Utility methods
  // ---------------------------------------------------------------------------

  protected Map<String, IDL> getCache(final Map<Object, Object> context) {
    Map<String, IDL> cache = contextualCache.get(context);
    if (cache == null) {
      cache = new HashMap<String, IDL>();
      contextualCache.set(context, cache);
    }
    return cache;
  }
}
